@@ -41,4 +41,17 @@ sub notify_incident {
     $self->_request('POST', '/api/v1/notifications', $params);
 }
 
+sub send_message {
+    my ($self, $incident_id, $text) = @_;
+    Carp::croak '[ERROR] Incident id is required' unless $incident_id;
+    Carp::croak '[ERROR] Message is required' unless $text;
+
+    my $params = {
+        incident_id => $incident_id,
+        message     => $text,
+    };
+
+    $self->_request('POST', '/api/v1/messages', $params);
+}
+
 1;
